# create-lillie

## Usage:

```bash
create-lillie YOUR_PROJECT_NAME --is-empty
```
* create-lillie - cli name
* YOUR_PROJECT_NAME - name for your project
* --is-empty - if used, will generate empty project, if not, will generate starter project

## Requirements:
* git
* pip
* python
* nodejs